palette

package
v0.0.0-...-b4425be Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 22, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package palette holds the JAB Code module color palettes shared by the encoder and decoder.

Index

Constants

This section is empty.

Variables

var Default = [8 * 3]byte{
	0, 0, 0,
	0, 0, 255,
	0, 255, 0,
	0, 255, 255,
	255, 0, 0,
	255, 0, 255,
	255, 255, 0,
	255, 255, 255,
}

Default is the 8-color default module palette as RGB triples: black, blue, green, cyan, red, magenta, yellow, white.

Functions

func SetDefault

func SetDefault(colorNumber int) []byte

SetDefault returns the default module color palette as RGB triples for the given color count.

func SetDefaultVariant

func SetDefaultVariant(colorNumber int, variant wire.Variant) []byte

SetDefaultVariant returns the default module color palette for the selected wire-format variant.

Types

This section is empty.

Jump to