Documentation
¶
Overview ¶
Package palette holds the JAB Code module color palettes shared by the encoder and decoder.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Default = [8 * 3]byte{
0, 0, 0,
0, 0, 255,
0, 255, 0,
0, 255, 255,
255, 0, 0,
255, 0, 255,
255, 255, 0,
255, 255, 255,
}
Default is the 8-color default module palette as RGB triples: black, blue, green, cyan, red, magenta, yellow, white.
Functions ¶
func SetDefault ¶
SetDefault returns the default module color palette as RGB triples for the given color count.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.